import { App } from '@kevisual/router';

type Opts = {
  prefix: string;
};
export const prefixFix = (data: any, prefix: string, opts?: Opts) => {
  const len = prefix.length || 0;
  if (data.data.files) {
    data.data.files = data.data.files.map((item) => {
      return {
        ...item,
        path: item.path.slice(len + 1),
      };
    });
  }
  return data;
};

/**
 * 根据username获取uid
 * @param app
 * @param ctx
 * @param username
 * @returns
 */
export const getUidByUsername = async (app: App, ctx: any, username?: string) => {
  const tokenUser = ctx.state.tokenUser;
  let uid = tokenUser.id; // TODO: 需要根据username来判断
  if (username) {
    // 这个用户的数据，tokenUser具有这个org的权限才行。真实用户的那个org
    const res = await app.call({
      path: 'org',
      key: 'hasUser',
      payload: {
        data: {
          username,
        },
        token: ctx.query.token,
      },
    });
    if (res.code === 200 && res.body?.uid) {
      uid = res.body.uid;
    } else {
      ctx.throw(500, 'user not found');
    }
  }
  return uid;
};
